#ifndef ELM_PAN_IMPL_HH
#define ELM_PAN_IMPL_HH

#include "elm_pan.eo.hh"

namespace elm { 
inline ::efl::eolian::return_traits<void>::type Pan::pos_get( ::efl::eolian::out_traits<int>::type x,  ::efl::eolian::out_traits<int>::type y) const
{
   int __out_param_x = {};
   int __out_param_y = {};
    ::elm_obj_pan_pos_get(_eo_ptr()
      , & __out_param_x
      , & __out_param_y);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(x, __out_param_x);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(y, __out_param_y);
}
inline ::efl::eolian::return_traits<void>::type Pan::pos_set( ::efl::eolian::in_traits<int>::type x,  ::efl::eolian::in_traits<int>::type y) const
{
    ::elm_obj_pan_pos_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(x)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(y));
}
inline ::efl::eolian::return_traits<void>::type Pan::content_size_get( ::efl::eolian::out_traits<int>::type w,  ::efl::eolian::out_traits<int>::type h) const
{
   int __out_param_w = {};
   int __out_param_h = {};
    ::elm_obj_pan_content_size_get(_eo_ptr()
      , & __out_param_w
      , & __out_param_h);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(w, __out_param_w);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(h, __out_param_h);
}
inline ::efl::eolian::return_traits<void>::type Pan::pos_min_get( ::efl::eolian::out_traits<int>::type x,  ::efl::eolian::out_traits<int>::type y) const
{
   int __out_param_x = {};
   int __out_param_y = {};
    ::elm_obj_pan_pos_min_get(_eo_ptr()
      , & __out_param_x
      , & __out_param_y);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(x, __out_param_x);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(y, __out_param_y);
}
inline ::efl::eolian::return_traits<void>::type Pan::pos_max_get( ::efl::eolian::out_traits<int>::type x,  ::efl::eolian::out_traits<int>::type y) const
{
   int __out_param_x = {};
   int __out_param_y = {};
    ::elm_obj_pan_pos_max_get(_eo_ptr()
      , & __out_param_x
      , & __out_param_y);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(x, __out_param_x);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(y, __out_param_y);
}
} 
namespace eo_cxx {
namespace elm { 
inline ::efl::eolian::return_traits<void>::type Pan::pos_get( ::efl::eolian::out_traits<int>::type x,  ::efl::eolian::out_traits<int>::type y) const
{
   int __out_param_x = {};
   int __out_param_y = {};
    ::elm_obj_pan_pos_get(_eo_ptr()
      , & __out_param_x
      , & __out_param_y);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(x, __out_param_x);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(y, __out_param_y);
}
inline ::efl::eolian::return_traits<void>::type Pan::pos_set( ::efl::eolian::in_traits<int>::type x,  ::efl::eolian::in_traits<int>::type y) const
{
    ::elm_obj_pan_pos_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(x)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(y));
}
inline ::efl::eolian::return_traits<void>::type Pan::content_size_get( ::efl::eolian::out_traits<int>::type w,  ::efl::eolian::out_traits<int>::type h) const
{
   int __out_param_w = {};
   int __out_param_h = {};
    ::elm_obj_pan_content_size_get(_eo_ptr()
      , & __out_param_w
      , & __out_param_h);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(w, __out_param_w);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(h, __out_param_h);
}
inline ::efl::eolian::return_traits<void>::type Pan::pos_min_get( ::efl::eolian::out_traits<int>::type x,  ::efl::eolian::out_traits<int>::type y) const
{
   int __out_param_x = {};
   int __out_param_y = {};
    ::elm_obj_pan_pos_min_get(_eo_ptr()
      , & __out_param_x
      , & __out_param_y);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(x, __out_param_x);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(y, __out_param_y);
}
inline ::efl::eolian::return_traits<void>::type Pan::pos_max_get( ::efl::eolian::out_traits<int>::type x,  ::efl::eolian::out_traits<int>::type y) const
{
   int __out_param_x = {};
   int __out_param_y = {};
    ::elm_obj_pan_pos_max_get(_eo_ptr()
      , & __out_param_x
      , & __out_param_y);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(x, __out_param_x);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(y, __out_param_y);
}
inline elm::Pan::operator ::elm::Pan() const { return *static_cast< ::elm::Pan const*>(static_cast<void const*>(this)); }
inline elm::Pan::operator ::elm::Pan&() { return *static_cast< ::elm::Pan*>(static_cast<void*>(this)); }
inline elm::Pan::operator ::elm::Pan const&() const { return *static_cast< ::elm::Pan const*>(static_cast<void const*>(this)); }
} }
#endif
